@@ -41,12 +41,12 @@ GD77::codeplug() {
 RadioInfo
 GD77::defaultRadioInfo() {
   return RadioInfo(
-        RadioInfo::GD77, "gd77", "GD-77", "Radioddity", RadioddityInterface::interfaceInfo());
+        RadioInfo::GD77, "gd77", "GD-77", "Radioddity", {RadioddityInterface::interfaceInfo()});
 }
 
 
 bool
-GD77::startUploadCallsignDB(UserDatabase *db, bool blocking, const CallsignDB::Selection &selection, const ErrorStack &err) {
+GD77::startUploadCallsignDB(UserDatabase *db, bool blocking, const CallsignDB::Flags &selection, const ErrorStack &err) {
   logDebug() << "Start call-sign DB upload to " << name() << "...";
   _errorStack = err;
 
@@ -91,15 +91,14 @@ GD77::uploadCallsigns()
 
   size_t totb = _callsigns.memSize();
   unsigned bcount = 0;
-  // Then upload callsign DB
   for (int n=0; n<_callsigns.image(0).numElements(); n++) {
     unsigned addr = _callsigns.image(0).element(n).address();
     unsigned size = _callsigns.image(0).element(n).data().size();
     unsigned b0 = addr/BSIZE, nb = size/BSIZE;
-    RadioddityInterface::MemoryBank bank = (
-          (0x10000 > addr) ? RadioddityInterface::MEMBANK_CALLSIGN_LOWER : RadioddityInterface::MEMBANK_CALLSIGN_UPPER );
     for (unsigned b=0; b<nb; b++, bcount+=BSIZE) {
-      if (! _dev->write(bank, (b0+b)*BSIZE,
+      RadioddityInterface::MemoryBank bank = (
+            (0x10000 > (b0+b)*BSIZE) ? RadioddityInterface::MEMBANK_CALLSIGN_LOWER : RadioddityInterface::MEMBANK_CALLSIGN_UPPER );
+      if (! _dev->write(bank, ((b0+b)*BSIZE)&0xffff,
                         _callsigns.data((b0+b)*BSIZE, 0), BSIZE, _errorStack))
       {
         errMsg(_errorStack) << "Cannot write block " << (b0+b) << ".";
@@ -109,6 +108,7 @@ GD77::uploadCallsigns()
     }
   }
 
+
   _dev->write_finish();
   return true;
 }
