@@ -32,7 +32,7 @@ OpenGD77BaseCallsignDB::DatabaseEntryElement::DatabaseEntryElement(uint8_t *ptr)
 
 void
 OpenGD77BaseCallsignDB::DatabaseEntryElement::clear() {
-  memset(_data, 0xff, size());
+  memset(_data, 0x00, size());
 }
 
 void
@@ -42,30 +42,58 @@ OpenGD77BaseCallsignDB::DatabaseEntryElement::setId(unsigned int id) {
 
 void
 OpenGD77BaseCallsignDB::DatabaseEntryElement::setText(const QString &text) {
+  QByteArray data = pack(text);
+  auto n = std::min(3*Limit::textLength()/4, (unsigned int)data.size());
+  memcpy(_data+Offset::text(), data.constData(), n);
+}
+
+bool
+OpenGD77BaseCallsignDB::DatabaseEntryElement::fromEntry(const UserDatabase::User &user) {
+  clear();
+  setId(user.id);
+
+  QString txt;
+  QTextStream stream(&txt);
+  stream << user.call << " " << user.name;
+  if (! user.city.isEmpty())
+    stream << " " << user.city;
+  if (! user.state.isEmpty())
+    stream << " " << user.state;
+  if (! user.country.isEmpty())
+    stream << " " << user.country;
+  setText(txt);
+
+  return true;
+}
+
+QByteArray
+OpenGD77BaseCallsignDB::DatabaseEntryElement::pack(const QString &text) {
+  // Encode chars
   QVector<uint> codes;
   foreach (QChar c, text) {
     if (! _lut.contains(c))
       continue;
     codes.append(_lut.indexOf(c));
   }
-  // Fix size
-  codes.resize(Limit::textLength());
-  // Encode in blocks of 4
+
+  // Fix size to multiples of 4
+  if (codes.size() % 4)
+    codes.resize(codes.size() + (4-(codes.size() % 4)));
+
+  // Pack
+  QByteArray data(3*codes.size()/4, '\x00');
   for (int i=0, o=0; i<codes.size(); i += 4, o += 3) {
     uint32_t encoded
-        = ((uint32_t)(codes[i+0] & 0x3f) << 18)
-        | ((uint32_t)(codes[i+1] & 0x3f) << 12)
-        | ((uint32_t)(codes[i+2] & 0x3f) << 06)
-        | ((uint32_t)(codes[i+3] & 0x3f) << 00);
-    setUInt24_be(Offset::text() + o, encoded);
+        = ((uint32_t)(codes[i+0] & 0x3f) << 18) |
+          ((uint32_t)(codes[i+1] & 0x3f) << 12) |
+          ((uint32_t)(codes[i+2] & 0x3f) << 06) |
+          ((uint32_t)(codes[i+3] & 0x3f) << 00);
+    data[o+0] = (encoded>>16) & 0xff;
+    data[o+1] = (encoded>> 8) & 0xff;
+    data[o+2] = (encoded>> 0) & 0xff;
   }
-}
 
-void
-OpenGD77BaseCallsignDB::DatabaseEntryElement::fromEntry(const UserDatabase::User &user) {
-  clear();
-  setId(user.id);
-  setText(user.call + " " + user.name + " " + user.city);
+  return data;
 }
 
 
@@ -91,11 +119,16 @@ OpenGD77BaseCallsignDB::DatabaseHeaderElement::clear() {
   memset(_data, 0, size());
   writeASCII(Offset::magic(), "Id", 2);
   setUInt8(Offset::format(), (unsigned int)Format::Compressed);
-  setUInt8(Offset::entrySize(), 0x59); // = 15 bytes -> 16 chars for text
+  setEntrySize(16); // Default text length = 16
   writeASCII(Offset::version(),"001", 3);
   setUInt32_le(Offset::entryCount(), 0);
 }
 
+void
+OpenGD77BaseCallsignDB::DatabaseHeaderElement::setEntrySize(unsigned int size) {
+  setUInt8(Offset::entrySize(), 0x4a+size);
+}
+
 void
 OpenGD77BaseCallsignDB::DatabaseHeaderElement::setEntryCount(unsigned int count) {
   setUInt32_le(Offset::entryCount(), count);
